@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2024 Univention GmbH
 #
 # https://www.univention.de/
@@ -32,7 +30,6 @@
 import itertools
 import re
 from logging import getLogger
-from typing import List, Optional  # noqa: F401
 
 import univention.admin
 import univention.admin.localization
@@ -50,11 +47,11 @@ _ = translation.translate
 # TODO move to univention.admin.syntax
 class GuardianRole(simple):
     regex = re.compile(
-        r"^([a-z0-9-_]+:[a-z0-9-_]+:[a-z0-9-_]+)(&[a-z0-9-_]+:[a-z0-9-_]+:[a-z0-9-_]+)?$"
+        r"^([a-z0-9-_]+:[a-z0-9-_]+:[a-z0-9-_]+)(&[a-z0-9-_]+:[a-z0-9-_]+:[a-z0-9-_]+)?$",
     )
     error_message = _(
         "Guardian role strings must be lowercase ASCII alphanumeric with hyphens and underscores, "
-        "in the format 'app:namespace:role' or 'app:namespace:role&app:namespace:context'!"
+        "in the format 'app:namespace:role' or 'app:namespace:role&app:namespace:context'!",
     )
 
 
@@ -65,7 +62,7 @@ def member_role_properties():
             long_description=_("Lowercase ASCII alphanumeric string with underscores or dashes, in the format 'app:namespace:role' or 'app:namespace:role&app:namespace:context'"),
             syntax=GuardianRole,
             multivalue=True,
-        )
+        ),
     }
 
 
@@ -118,25 +115,25 @@ def role_layout():
         advanced=True,
         layout=[
             'guardianRoles',
-            'guardianInheritedRoles'
+            'guardianInheritedRoles',
         ],
     )
 
 
 @univention.admin._ldap_cache(ttl=60)
-def get_group_role(lo, dn):  # type: (univention.admin.uldap.access, str) -> list[str]
+def get_group_role(lo: univention.admin.uldap.access, dn: str) -> list[str]:
     res = lo.get(dn, attr=['univentionGuardianMemberRoles'])
     return [x.decode('UTF-8') for x in res.get('univentionGuardianMemberRoles', [])]
 
 
 # TODO
 # naive approach to get role strings for groups by searching the LDAP
-def load_roles(lo, groups):  # type: (univention.admin.uldap.access, List[str], bool) -> List[str]
+def load_roles(lo: univention.admin.uldap.access, groups: list[str]) -> list[str]:
     return list(set(itertools.chain.from_iterable(get_group_role(lo, group) for group in groups)))
 
 
-class GuardianBase(object):
-    def open_guardian(self):  # type: () -> None
+class GuardianBase:
+    def open_guardian(self) -> None:
         if self.exists():
             self.info['guardianInheritedRoles'] = load_roles(self.lo, self['groups'] + [self['primaryGroup']])
             self.save()
