@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -291,7 +290,7 @@ class object(ComputerObject):
     @classmethod
     def lookup_filter(cls, filter_s=None, lo=None):
         # type: (str | None, univention.admin.uldap.access | None) -> univention.admin.filter.conjunction
-        con = super(object, cls).lookup_filter(filter_s, lo)
+        con = super().lookup_filter(filter_s, lo)
         con.expressions.append(
             univention.admin.filter.conjunction('|', [
                 univention.admin.filter.expression('objectClass', 'posixAccount'),
