@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -107,8 +106,8 @@ def unmapHWAddress(old, encoding=()):
     """
     log.debug('host.py: unmapHWAddress: old: %s', old)
     if not old:
-        return [u'', u'']
-    return old[0].decode(*encoding).split(u' ')
+        return ['', '']
+    return old[0].decode(*encoding).split(' ')
 
 
 def mapHWAddress(old, encoding=()):
@@ -130,7 +129,7 @@ def mapHWAddress(old, encoding=()):
         return b''
 
     if len(old) > 1:
-        value = u'%s %s' % (old[0], old[1])
+        value = '%s %s' % (old[0], old[1])
         return value.encode(*encoding)
 
     return old[0].encode(*encoding)
@@ -149,10 +148,10 @@ class object(DHCPBase):
 
     @classmethod
     def rewrite_filter(cls, filter, mapping):
-        if filter.variable == u'hwaddress' and not isinstance(filter.value, list) and filter.value:
+        if filter.variable == 'hwaddress' and not isinstance(filter.value, list) and filter.value:
             # unmap() the value to a list so that the following rewrite_filter() map()s it
             filter.value = unmapHWAddress([filter.value.encode('UTF-8')])
-        super(object, cls).rewrite_filter(filter, mapping)
+        super().rewrite_filter(filter, mapping)
 
 
 lookup_filter = object.lookup_filter
