@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -33,16 +32,12 @@
 
 """|UDM| module for all nagios settings"""
 
-from typing import TYPE_CHECKING
 
+import univention.admin
 import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.localization
-
-
-if TYPE_CHECKING:
-    import univention.admin
-    import univention.admin.uldap
+import univention.admin.uldap
 
 
 translation = univention.admin.localization.translation('univention.admin.handlers.nagios')
