@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -35,8 +34,9 @@
 
 import base64
 import inspect
+from collections.abc import Callable, Iterable  # noqa: F401
 from logging import getLogger
-from typing import Any, Callable, Iterable, Tuple, TypeVar  # noqa: F401
+from typing import TypeVar
 
 import univention.admin.uexceptions
 from univention.admin import localization
@@ -49,19 +49,19 @@ translation = localization.translation('univention/admin')
 _ = translation.translate
 
 _E = TypeVar('_E')  # noqa: PYI018
-_Encoding = Tuple[str, ...]
+_Encoding = tuple[str, ...]
 
 
 def MapToBytes(udm_value, encoding=()):
     # type: (list[str] | tuple[str, ...] | str, _Encoding) -> list[bytes] | bytes
-    if isinstance(udm_value, (list, tuple)):
+    if isinstance(udm_value, list | tuple):
         return [MapToBytes(udm_val, encoding=encoding) for udm_val in udm_value]
     return str(udm_value).encode(*encoding)
 
 
 def UnmapToUnicode(ldap_value, encoding=()):
     # type: (list[bytes] | tuple[bytes, ...] | bytes, _Encoding) -> list[str] | str
-    if isinstance(ldap_value, (list, tuple)):
+    if isinstance(ldap_value, list | tuple):
         return [UnmapToUnicode(ldap_val, encoding=encoding) for ldap_val in ldap_value]
     return ldap_value.decode(*encoding)
 
@@ -144,7 +144,7 @@ def ListToString(value, encoding=()):
     if value:
         return UnmapToUnicode(value, encoding)[0]
     else:
-        return u''
+        return ''
 
 
 def ListToIntToString(list_):
@@ -231,7 +231,7 @@ def IgnoreNone(value, encoding=()):
     b'1'
     >>> IgnoreNone('None')
     """
-    if value != u'None':
+    if value != 'None':
         return value.encode(*encoding)
     return None  # FIXME
 
@@ -274,19 +274,19 @@ def unmapUNIX_TimeInterval(seconds):
     >>> unmapUNIX_TimeInterval('86400')  # doctest: +ALLOW_UNICODE
     ['1', 'days']
     """
-    if isinstance(seconds, (list, tuple)):
+    if isinstance(seconds, list | tuple):
         seconds = seconds[0]
     value = _stringToInt(seconds)
-    unit = u'seconds'
+    unit = 'seconds'
     if value % 60 == 0:
         value //= 60
-        unit = u'minutes'
+        unit = 'minutes'
         if value % 60 == 0:
             value //= 60
-            unit = u'hours'
+            unit = 'hours'
             if value % 24 == 0:
                 value //= 24
-                unit = u'days'
+                unit = 'days'
     return [str(value), unit]
 
 
@@ -308,16 +308,16 @@ def mapUNIX_TimeInterval(value):
     b'60'
     """
     unit = 'seconds'
-    if isinstance(value, (tuple, list)):
+    if isinstance(value, tuple | list):
         if len(value) > 1:
             unit = value[1]
         value = value[0]
     val = _stringToInt(value)
-    if unit == u'days':
+    if unit == 'days':
         val *= 24 * 60 * 60
-    elif unit == u'hours':
+    elif unit == 'hours':
         val *= 60 * 60
-    elif unit == u'minutes':
+    elif unit == 'minutes':
         val *= 60
     return str(val).encode('ASCII')
 
@@ -397,8 +397,8 @@ def BooleanListToString(list, encoding=()):
     '1'
     """
     v = ListToString(list, encoding=encoding)
-    if v == u'0':
-        return u''
+    if v == '0':
+        return ''
     return v
 
 
@@ -415,16 +415,16 @@ def BooleanUnMap(value, encoding=()):
     >>> BooleanUnMap('1')
     b'1'
     """
-    if value == u'0':
+    if value == '0':
         return b''
     return value.encode(*encoding)
 
 
-class dontMap(object):
+class dontMap:
     """'Do nothing' mapping."""
 
 
-class mapping(object):
+class mapping:
     """Map |LDAP| attribute names and values to |UDM| property names and values and back."""
 
     def __init__(self):
@@ -577,7 +577,7 @@ class mapping(object):
         encoding, errors = self.getEncoding(map_name)
         errors = encoding_errors or errors
         value = self.mapValue(map_name, value, encoding_errors=errors)
-        if isinstance(value, (list, tuple)):
+        if isinstance(value, list | tuple):
             log.warning('mapValueDecoded returns a list for %s. This is probably not wanted?', map_name)
             value = [val.decode(encoding, errors) for val in value]
         else:
