@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -64,7 +63,7 @@ def get_file_type(filename_or_file):
         with open(filename_or_file, 'rb') as fp:
             txt = fp.read()
     else:
-        raise ValueError('Argument "filename_or_file" has unknown type {!r}.'.format(type(filename_or_file)))
+        raise ValueError(f'Argument "filename_or_file" has unknown type {type(filename_or_file)!r}.')
 
     if hasattr(magic, 'from_file'):
         mime = magic.Magic(mime=True, mime_encoding=True).from_buffer(txt)
@@ -86,7 +85,7 @@ def get_file_type(filename_or_file):
     return FileType(mime_type, encoding, text)
 
 
-class BaseBinaryProperty(object):
+class BaseBinaryProperty:
     """
     Container for a binary UDM property.
 
@@ -109,7 +108,7 @@ class BaseBinaryProperty(object):
 
     def __repr__(self):
         # type: () -> str
-        return '{}({})'.format(self.__class__.__name__, self._name)
+        return f'{self.__class__.__name__}({self._name})'
 
     @property
     def encoded(self):
